@@ -92,7 +92,7 @@
         return document.createElementNS(namespace, tag);
     }
 
-    function classes(...args) {
+    function classes$1(...args) {
         const classes = [];
         args.filter((c) => Boolean(c)).forEach((c) => {
             if (typeof c === "string") {
@@ -151,8 +151,8 @@
 
     function setClassObject(element, classObj) {
         const cls = Array.isArray(classObj)
-            ? classes(...classObj)
-            : classes(classObj);
+            ? classes$1(...classObj)
+            : classes$1(classObj);
         if (cls) {
             element.setAttribute("class", cls);
         } else {
@@ -1114,7 +1114,7 @@
         vdom.execute(vnode, old);
         return vdom.getVNodeContext(vnode);
     }
-    function render(element, spec) {
+    function render$1(element, spec) {
         const vnode = createDOMVNode(
             element,
             Array.isArray(spec) ? spec : [spec],
@@ -1179,7 +1179,7 @@
         }
     })();
 
-    function classes$1(...args) {
+    function classes(...args) {
         const classes = [];
         args.filter((c) => Boolean(c)).forEach((c) => {
             if (typeof c === "string") {
@@ -1254,7 +1254,7 @@
     }
     function mergeClass(cls, propsCls) {
         const normalized = toArray(cls).concat(toArray(propsCls));
-        return classes$1(...normalized);
+        return classes(...normalized);
     }
     function omitAttrs(omit, attrs) {
         const result = {};
@@ -1284,17 +1284,18 @@
         const c = (1 - Math.abs(2 * l - 1)) * s;
         const x = c * (1 - Math.abs(((h / 60) % 2) - 1));
         const m = l - c / 2;
-        const [r, g, b] = (h < 60
-            ? [c, x, 0]
-            : h < 120
-            ? [x, c, 0]
-            : h < 180
-            ? [0, c, x]
-            : h < 240
-            ? [0, x, c]
-            : h < 300
-            ? [x, 0, c]
-            : [c, 0, x]
+        const [r, g, b] = (
+            h < 60
+                ? [c, x, 0]
+                : h < 120
+                ? [x, c, 0]
+                : h < 180
+                ? [0, c, x]
+                : h < 240
+                ? [0, x, c]
+                : h < 300
+                ? [x, 0, c]
+                : [c, 0, x]
         ).map((n) => Math.round((n + m) * 255));
         return {r, g, b, a};
     }
@@ -1711,7 +1712,7 @@
         const rgb = hsbToRGB(hsb);
         return rgbToHexString(rgb);
     }
-    function render$1(canvas, getPixel) {
+    function render(canvas, getPixel) {
         const {width, height} = canvas;
         const context = canvas.getContext("2d");
         const imageData = context.getImageData(0, 0, width, height);
@@ -1729,7 +1730,7 @@
     }
     function renderHue(canvas) {
         const {height} = canvas;
-        render$1(canvas, (_, y) => {
+        render(canvas, (_, y) => {
             const hue = scale(y, 0, height, 0, 360);
             const {r, g, b} = hsbToRGB({h: hue, s: 1, b: 1});
             return new Uint8ClampedArray([r, g, b, 255]);
@@ -1737,7 +1738,7 @@
     }
     function renderSB(hue, canvas) {
         const {width, height} = canvas;
-        render$1(canvas, (x, y) => {
+        render(canvas, (x, y) => {
             const sat = scale(x, 0, width - 1, 0, 1);
             const br = scale(y, 0, height - 1, 1, 0);
             const {r, g, b} = hsbToRGB({h: hue, s: sat, b: br});
@@ -1775,7 +1776,8 @@
         }
         function createHSBSwipeHandler(getEventHSB) {
             return createSwipeHandler((startEvt, startNativeEvt) => {
-                const rect = startNativeEvt.currentTarget.getBoundingClientRect();
+                const rect =
+                    startNativeEvt.currentTarget.getBoundingClientRect();
                 function onPointerMove(e) {
                     store.activeHSB = getEventHSB({...e, rect});
                     props.onColorPreview(hsbToString(store.activeHSB));
@@ -2040,11 +2042,11 @@
             } else {
                 clickListeners.delete(node);
             }
-            render(node, content);
+            render$1(node, content);
         });
         context.onRemove(() => {
             const container = getOverlayDOMNode(props.key);
-            render(container, null);
+            render$1(container, null);
         });
         return context.leave();
     }
